@@ -5,7 +5,7 @@ from slai.login import Login
 from slai import loaders
 from slai.model import Model
 
-__version__ = "0.1.25"
+__version__ = "0.1.33"
 
 
 # most used slai actions go here
@@ -13,7 +13,7 @@ model = Model
 model_version = ModelVersion
 loaders = loaders
 inputs = ModelInputs
-base_handler = BaseModelHandler
+BaseModelHandler = BaseModelHandler
 login = Login
 
 
