@@ -12,6 +12,8 @@ def get_api_base_url():
             key="BASE_URL",
             default="http://localhost:5000",
         )
+    elif stage == "docker":
+        base_url = "http://host.docker.internal:5000"
     else:
         base_url = from_config(
             key="BASE_URL",
