@@ -1,6 +1,7 @@
 import requests
 import sys
 
+from http import HTTPStatus
 from slai.clients.identity import get_identity_client
 from slai.modules.parameters import from_config
 from slai.modules.runtime import detect_credentials, detect_runtime, ValidRuntimes
@@ -16,12 +17,12 @@ from getpass import getpass
 class Login:
     APP_BASE_URL = from_config(
         key="APP_BASE_URL",
-        default="https://dev.slai.io",
+        default="https://beta.slai.io",
     )
 
-    def __init__(self, *, client_id=None, client_secret=None):
+    def __init__(self, *, client_id=None, client_secret=None, key_type=None):
         self.identity_client = get_identity_client(
-            client_id=client_id, client_secret=client_secret
+            client_id=client_id, client_secret=client_secret, key_type=key_type
         )
 
         if client_id is None or client_secret is None:
@@ -34,9 +35,12 @@ class Login:
 
     def _validate_credentials(self):
         try:
-            _ = self.identity_client.get_user()
-        except requests.exceptions.HTTPError:
-            self.authenticated = False
+            _ = self.identity_client.validate_credentials()
+        except requests.exceptions.HTTPError as e:
+            if e.response.status_code == HTTPStatus.BAD_REQUEST:
+                if e.response.json()["detail"][0] == "invalid_key_type":
+                    raise InvalidCredentials("invalid_key_type")
+
             raise InvalidCredentials("invalid_credentials")
 
         # cache credentials on slai module
