@@ -4,18 +4,25 @@ import sys
 
 from slai.dataset import DataSet
 from slai.clients.model import get_model_client
-from slai.exceptions import UnsupportedModelFormat, UnableToConvertNotebook
+from slai.exceptions import (
+    UnsupportedModelFormat,
+    UnableToConvertNotebook,
+    InvalidModelURI,
+)
 from slai.modules.model_saver import ModelSaver, ValidModelFrameworks
 from slai.modules.runtime import detect_runtime, ValidRuntimes
 from slai.modules import notebook_utils
+from slai.constants import MODEL_ROUTE_URI
 
 
 class ModelVersion:
-    def __init__(self, *, model_name, project_name, model_version_id=None):
+    def __init__(self, model_uri):
+        self._parse_model_uri(model_uri)
+
         self.runtime = detect_runtime()
 
-        self.model_name = model_name
-        self.project_name = project_name
+        self.model_name = self.model_name
+        self.project_name = self.project_name
 
         self.model_client = get_model_client(
             model_name=self.model_name, project_name=self.project_name
@@ -23,18 +30,51 @@ class ModelVersion:
         self.project = self.model_client.project_client.get_project()
         self.model = self.model_client.get_model()
 
-        if model_version_id is None:
-            self.model_version_id = self.get_version()
+        if self.model_version_name is None:
+            self.model_version_id = self.get_model_version_id()
+            self.model_version_name = self.model_version["name"]
         else:
-            self.model_version_id = model_version_id
+            self.model_version = self.model_client.get_model_version_by_name(
+                model_version_name=self.model_version_name
+            )
+            self.model_version_id = self.model_version["id"]
 
-    def get_version(self):
+    def _parse_model_uri(self, model_uri):
+        m = re.match(MODEL_ROUTE_URI, model_uri)
+        if not m:
+            raise InvalidModelURI("invalid_model_route")
+
+        project_name = m.group(1)
+        model_name = m.group(2)
+        model_version_name = m.group(3)
+
+        if model_version_name == "":
+            model_version_name = None
+
+        self.project_name = project_name
+        self.model_name = model_name
+        self.model_version_name = model_version_name
+
+    def get_model_version_id(self):
         if self.model_version_id is None:
             self.model = self.model_client.get_model()
             self.model_version_id = self.model["model_version_id"]
+            self.model_version = self.model_client.get_model_version_by_id(
+                model_version_id=self.model_version_id
+            )
 
         return self.model_version_id
 
+    def get_model_version(self):
+        if self.model_version_id is None:
+            self.model = self.model_client.get_model()
+            self.model_version_id = self.model["model_version_id"]
+            self.model_version = self.model_client.get_model_version_by_id(
+                model_version_id=self.model_version_id
+            )
+
+        return self.model_version
+
     def dataset(self):
         return DataSet(model=self.model, model_version=self.model_version_id)
 
@@ -43,7 +83,7 @@ class ModelVersion:
 
         if model is not None:
             _model_class = repr(model.__class__.__bases__[0])
-            _matches = re.findall(r"\<class\s\'([a-zA-Z0-9\.]+)\'\>", _model_class)
+            _matches = re.findall(r"\<class\s\'([a-zA-Z0-9\.\_]+)\'\>", _model_class)
 
             if len(_matches) >= 1:
                 module = _matches[0].split(".")[0].upper()
@@ -79,7 +119,7 @@ class ModelVersion:
         sys.modules["__main__"] = trainer_module
 
     def _handle_local_notebook_trainer(self):
-        notebook_path = f"/workspace/models/{self.model_name}/{self.model_version_id}/notebook.ipynb"  # noqa
+        notebook_path = f"/workspace/models/{self.model_name}/{self.model_version['name']}/notebook.ipynb"  # noqa
 
         imports, trainer = notebook_utils.parse_notebook(notebook_path)
         trainer_source = notebook_utils.generate_trainer_from_template(
@@ -88,9 +128,7 @@ class ModelVersion:
             trainer=trainer,
             model_version_id=self.model_version_id,
         )
-        trainer_path = (
-            f"/workspace/models/{self.model_name}/{self.model_version_id}/trainer.py"
-        )
+        trainer_path = f"/workspace/models/{self.model_name}/{self.model_version['name']}/trainer.py"  # noqa
 
         with open(trainer_path, "w") as f_out:
             f_out.write(trainer_source)
@@ -120,6 +158,8 @@ class ModelVersion:
         # torch
         if framework_name == ValidModelFrameworks.Torch:
             model_data, requirements = ModelSaver.save_pytorch(model)
+        elif framework_name == ValidModelFrameworks.Sklearn:
+            model_data, requirements = ModelSaver.save_sklearn(model)
         elif framework_name in []:
             pass
 
