@@ -52,6 +52,10 @@ def detect_credentials(*, runtime, profile_name="default"):
                 path=LOCAL_CREDENTIALS_PATHS["global"], credentials_type="global"
             )
             credentials = credentials.get(profile_name)
+
+            if not credentials:
+                raise NoCredentialsFound("no_credentials_found")
+
         else:
             raise NoCredentialsFound("no_credentials_found")
 
@@ -91,6 +95,7 @@ def _load_credentials(*, path, credentials_type="global"):
     if credentials_type == "global":
         return credentials
     elif credentials_type == "project" or credentials_type == "local_notebook":
+
         return {
             "client_id": credentials["client_id"],
             "client_secret": credentials["client_secret"],
